#
# spec file for package libvirt
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

# For now, default to a full server + client build
%define client_only        0

# Disable all server side drivers if client only build requested
%if %{client_only}
%define server_drivers     0
%else
%define server_drivers     1
%endif

# Now set the defaults for all the important features, independent
# of any particular OS

# First the daemon itself
%define with_libvirtd      0%{!?_without_libvirtd:%{server_drivers}}
%define with_avahi         0%{!?_without_avahi:%{server_drivers}}

# Then the hypervisor drivers that run on local host
%define with_xen           0%{!?_without_xen:%{server_drivers}}
%define with_qemu          0%{!?_without_qemu:%{server_drivers}}
%define with_openvz        0%{!?_without_openvz:%{server_drivers}}
%define with_lxc           0%{!?_without_lxc:%{server_drivers}}
%define with_vbox          0%{!?_without_vbox:%{server_drivers}}
%define with_uml           0%{!?_without_uml:%{server_drivers}}
%define with_xenapi        0%{!?_without_xenapi:%{server_drivers}}
%define with_libxl         0%{!?_without_libxl:%{server_drivers}}

# Then the hypervisor drivers that talk a native remote protocol
%define with_phyp          0%{!?_without_phyp:1}
%define with_esx           0%{!?_without_esx:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_hyperv	   0%{!?_without_hyperv:1}

# Then the secondary host drivers
%define with_network       0%{!?_without_network:%{server_drivers}}
%define with_storage_fs    0%{!?_without_storage_fs:%{server_drivers}}
%define with_storage_lvm   0%{!?_without_storage_lvm:%{server_drivers}}
%define with_storage_iscsi 0%{!?_without_storage_iscsi:%{server_drivers}}
%define with_storage_disk  0%{!?_without_storage_disk:%{server_drivers}}
%define with_storage_mpath 0%{!?_without_storage_mpath:%{server_drivers}}
%define with_numactl       0%{!?_without_numactl:%{server_drivers}}
%define with_selinux       0%{!?_without_selinux:%{server_drivers}}
%define with_apparmor      0%{!?_without_apparmor:0}

# A few optional bits off by default, we enable later
%define with_polkit        0%{!?_without_polkit:0}
%define with_capng         0%{!?_without_capng:0}
%define with_netcf         0%{!?_without_netcf:0}
%define with_udev          0%{!?_without_udev:0}
%define with_hal           0%{!?_without_hal:0}
%define with_yajl          0%{!?_without_yajl:0}
%define with_nwfilter      0%{!?_without_nwfilter:0}
%define with_libpcap       0%{!?_without_libpcap:0}
%define with_macvtap       0%{!?_without_macvtap:0}
%define with_libnl         0%{!?_without_libnl:0}
%define with_audit         0%{!?_without_audit:0}
%define with_dtrace        0%{!?_without_dtrace:0}
%define with_cgconfig      0%{!?_without_cgconfig:0}

# Non-server/HV driver defaults which are always enabled
%define with_python        0%{!?_without_python:1}
%define with_sasl          0%{!?_without_sasl:1}

# Set the OS / architecture specific special cases

# Xen is available only on i386 x86_64
%ifnarch %ix86 x86_64
%define with_xen           0
%define with_libxl         0
%endif

# libxenlight driver requires Xen >= 4.1, which is only
# available in openSUSE >= 12.1 or SLE >= 11sp2
%if 0%{?suse_version} < 1210
%define with_libxl         0
%endif

# numactl only on x86_64 and ia64
%ifnarch x86_64 ia64
%define with_numactl       0
%endif

# SLES doesn't contain OpenVZ, VBox, UML, ESX, VMWare, or Citrix XenAPI
%if 0%{?sles_version}
%define with_openvz        0
%define with_vbox          0
%define with_uml           0
%define with_esx           1
%define with_vmware        1
%define with_hyperv	   1
%define with_xenapi        1
%endif

# Enable phyp driver for IBM Power systems
%ifarch ppc64
%define with_phyp          1
%endif

# LXC and selinux are not available on anything < openSUSE 11.1
%if 0%{?suse_version} < 1110
%define with_lxc           0
%define with_selinux       0
%endif

# udev is used to manage host devices in 11.1 or newer
%if 0%{?suse_version} > 1110
%define with_udev          0%{!?_without_udev:%{server_drivers}}
%else
%define with_hal           0%{!?_without_hal:%{server_drivers}}
%endif

# libcapng is used to manage capabilities in 11.3 or newer.
# It is also used by lxc and needs to be enabled if lxc is enabled.
%if 0%{?suse_version} >= 1130 || %{with_lxc}
%define with_capng         0%{!?_without_capng:1}
%endif

# netcf is used to manage network interfaces in 11.4 or newer
%if 0%{?suse_version} >= 1140
%define with_netcf         0%{!?_without_netcf:%{server_drivers}}
%endif

# Enable yajl library for JSON mode with QEMU in 11.4 or newer
%if 0%{?suse_version} >= 1140
%define with_yajl          0%{!?_without_yajl:%{server_drivers}}
%endif

# Enable libpcap library
%if %{with_qemu}
%if 0%{?suse_version} >= 1140
%define with_nwfilter      0%{!?_without_nwfilter:%{server_drivers}}
%define with_libpcap       0%{!?_without_libpcap:%{server_drivers}}
%define with_macvtap       0%{!?_without_macvtap:%{server_drivers}}
%endif
%endif

%if %{with_macvtap}
%define with_libnl         1
%endif

# there's no use compiling the network driver without
# the libvirt daemon
%if ! %{with_libvirtd}
%define with_network       0
%endif

BuildRequires:  python-devel
BuildRequires:  libxml2-devel
BuildRequires:  xhtml-dtd
BuildRequires:  libxslt
BuildRequires:  readline-devel
BuildRequires:  ncurses-devel
BuildRequires:  gettext
BuildRequires:  gnutls-devel
BuildRequires:  bridge-utils
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  python-xml
# Only for directory ownership:
BuildRequires:  gtk-doc
%if %{with_xen} || %{with_libxl}
BuildRequires:  xen-devel
%endif
%if %{with_sasl}
BuildRequires:  cyrus-sasl-devel
%endif
%if %{with_hal}
BuildRequires:  hal-devel
%endif
%if %{with_udev}
BuildRequires:  libudev-devel >= 145
BuildRequires:  libpciaccess0-devel >= 0.10.9
%endif
%if %{with_avahi}
%if 0%{?suse_version} > 1030
BuildRequires:  libavahi-devel
%else
BuildRequires:  avahi-devel
%endif
%endif
%if %{with_selinux}
BuildRequires:  libselinux-devel
%endif
%if %{with_apparmor}
BuildRequires:  libapparmor-devel
%endif
%if %{with_numactl}
BuildRequires:  libnuma-devel
%endif
%if %{with_polkit}
%if 0%{?suse_version} > 1110
BuildRequires:  polkit >= 0.9
%else
BuildRequires:  PolicyKit-devel >= 0.6
%endif
%endif
%if %{with_phyp}
BuildRequires:  libssh2-devel >= 1.0
Requires:	libssh2-1 >= 1.0
%endif
%if %{with_yajl}
BuildRequires:  libyajl-devel
%endif
%if %{with_macvtap}
BuildRequires:  libnl-devel
%endif
%if %{with_esx}
BuildRequires:  libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires:	libwsman-devel
%endif
%if %{with_capng}
BuildRequires:  libcap-ng-devel >= 0.5.0
%endif
%if %{with_netcf}
BuildRequires:  netcf-devel >= 0.1.4
%endif
%if %{with_network}
BuildRequires:  dnsmasq >= 2.41
BuildRequires:  iptables-devel
BuildRequires:  radvd
%endif
%if %{with_nwfilter}
BuildRequires:  ebtables
%endif
%if %{with_libpcap}
BuildRequires:  libpcap-devel
%endif
%if %{with_libnl}
BuildRequires:  libnl-devel
%endif
%if %{with_storage_fs}
# For mount/umount in FS driver
BuildRequires:  util-linux
%endif
%if %{with_storage_lvm}
# For LVM drivers
BuildRequires:  lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
BuildRequires:  open-iscsi
%endif
%if %{with_storage_disk}
# For disk driver
BuildRequires:  parted-devel
%endif
%if %{with_storage_mpath}
# For Multipath support
BuildRequires:  device-mapper-devel
%endif

Name:           libvirt
Url:            http://libvirt.org/
License:        LGPLv2.1+
Group:          Development/Libraries/C and C++
AutoReqProv:    yes
Version:        0.9.13
Release:        3.1
Summary:        A C toolkit to interract with the virtualization capabilities of Linux

# The client side, i.e. shared libs and virsh are in a subpackage
Requires:       %{name}-client = %{version}-%{release}
Requires:       virt-utils
# Used by many of the drivers, so turn it on whenever the
# daemon is present
%if %{with_libvirtd}
Recommends:     bridge-utils
# for modprobe of pci devices
Requires:       module-init-tools
# for /sbin/ip
Requires:       iproute
%endif
%if %{with_network}
Recommends:     dnsmasq >= 2.41
Recommends:     radvd
%endif
%if %{with_network} || %{with_nwfilter}
Recommends:     iptables
%endif
%if %{with_nwfilter}
Recommends:     ebtables
%endif
Recommends:     logrotate
Recommends:     nfs-client
%if %{with_hal}
Requires:       hal
%endif
Requires:       /usr/sbin/dmidecode
%if %{with_udev}
Requires:       udev >= 145
%endif
%if %{with_polkit}
%if 0%{?suse_version} > 1110
Recommends:     polkit >= 0.9
%else
Recommends:     PolicyKit >= 0.6
%endif
%endif
%if %{with_storage_fs}
Recommends:     nfs-utils
%endif
%if %{with_storage_lvm}
# For LVM drivers
Recommends:     lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
Recommends:     open-iscsi
%endif
%if %{with_storage_disk}
# For disk driver
Recommends:     parted
Recommends:     device-mapper
%endif
%if %{with_storage_mpath}
# For multipath support
Recommends:     device-mapper
%endif

Source0:        %{name}-%{version}.tar.bz2
Source1:        libvirtd.init
# Upstream patches
# Need to go upstream
Patch100:       xen-name-for-devid.patch
Patch101:       clone-0.9.10.patch
Patch102:       xen-pv-cdrom.patch
# Our patches
Patch200:       libvirtd-defaults-0.9.12.patch
Patch201:       use-init-script-redhat-0.9.12.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libvirt is a C toolkit to interact with the virtualization
capabilities of Linux. Virtualization of the Linux Operating System means
the ability to run multiple instances of Operating Systems concurrently
on a single hardware system where the basic resources are driven by a
Linux instance. The library aims to provide long term stable C API
to interact with Linux virtualization technologies.



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>

%package client
License:        LGPLv2.1+
Summary:        Client side library and utilities of the libvirt library
Group:          Development/Libraries/C and C++
Requires:       readline
Requires:       ncurses
# Needed by libvirt-guests init script.
Requires:       gettext
Requires:       cyrus-sasl
Recommends:     cyrus-sasl-digestmd5
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Recommends:     netcat-openbsd

%description client
Libvirt is a C toolkit to interract with the virtualization
capabilities of Linux.  The libvirt-client package contains shared
libraries and client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>

%package devel
License:        LGPLv2.1+
Summary:        A C toolkit to interract with the virtualization capabilities of Linux
Group:          Development/Libraries/C and C++
Requires:       %{name}-client = %{version}-%{release} libxml2-devel
Requires:       pkg-config
%if %{with_xen} || %{with_libxl}
Requires:       xen-devel
%endif

%description devel
Libvirt is a C toolkit to interract with the virtualization
capabilities of Linux. The libvirt-devel package contains headers
and libraries needed for developing libvirt applications.



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>

%package doc
License:        LGPLv2.1+
Summary:        A C toolkit to interract with the virtualization capabilities of Linux
Group:          Development/Libraries/C and C++
Requires:       %{name}-client = %{version}-%{release}

%description doc
Libvirt is a C toolkit to interract with the virtualization
capabilities of Linux. The libvirt-doc packages contains documentation
for the libvirt API and tools.



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>

%if %{with_python}

%package python
License:        LGPLv2.1+
Summary:        A C toolkit to interract with the virtualization capabilities of Linux
Group:          Development/Libraries/C and C++
Requires:       %{name}-client = %{version}-%{release}
%py_requires

%description python
Libvirt is a C toolkit to interract with the virtualization
capabilities of Linux.  The libvirt-python package provides python
bindings for the libvirt C API.



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>
%endif

%prep
%setup -q
%patch100 -p1
%patch101
%patch102 -p1
%patch200 -p1
%patch201 -p1

%build
%if ! %{with_xen}
%define _without_xen --without-xen
%endif
%if ! %{with_qemu}
%define _without_qemu --without-qemu
%endif
%if ! %{with_openvz}
%define _without_openvz --without-openvz
%endif
%if ! %{with_lxc}
%define _without_lxc --without-lxc
%endif
%if ! %{with_vbox}
%define _without_vbox --without-vbox
%endif
%if ! %{with_xenapi}
%define _without_xenapi --without-xenapi
%endif
%if ! %{with_uml}
%define _without_uml --without-uml
%endif
%if ! %{with_phyp}
%define _without_phyp --without-phyp
%endif
%if ! %{with_esx}
%define _without_esx --without-esx
%endif
%if ! %{with_vmware}
%define _without_vmware --without-vmware
%endif
%if ! %{with_hyperv}
%define _without_hyperv --without-hyperv
%endif
%if ! %{with_libxl}
%define _without_libxl --without-libxl
%endif
%if ! %{with_libvirtd}
%define _without_libvirtd --without-libvirtd
%endif
%if ! %{with_storage_fs}
%define _without_storage_fs --without-storage-fs
%endif
%if ! %{with_storage_lvm}
%define _without_storage_lvm --without-storage-lvm
%endif
%if ! %{with_storage_iscsi}
%define _without_storage_iscsi --without-storage-iscsi
%endif
%if ! %{with_storage_disk}
%define _without_storage_disk --without-storage-disk
%endif
%if ! %{with_storage_mpath}
%define _without_storage_mpath --without-storage-mpath
%endif
%if ! %{with_numactl}
%define _without_numactl --without-numactl
%endif
%if ! %{with_selinux}
%define _without_selinux --without-selinux
%endif
%if ! %{with_apparmor}
%define _without_apparmor --without-apparmor
%endif
%if ! %{with_capng}
%define _without_capng --without-capng
%endif
%if ! %{with_netcf}
%define _without_netcf --without-netcf
%endif
%if ! %{with_hal}
%define _without_hal --without-hal
%endif
%if ! %{with_udev}
%define _without_udev --without-udev
%endif
%if ! %{with_yajl}
%define _without_yajl --without-yajl
%endif
%if ! %{with_macvtap}
%define _without_macvtap --without-macvtap
%endif
%if ! %{with_polkit}
%define _without_polkit --without-polkit
%endif
%if ! %{with_network}
%define _without_network --without-network
%endif
%if ! %{with_sasl}
%define _without_sasl --without-sasl
%endif
%if ! %{with_python}
%define _without_python --without-python
%endif
%if ! %{with_libpcap}
%define _without_libpcap --without-libpcap
%endif

autoreconf -f -i
export CFLAGS="$RPM_OPT_FLAGS"
%configure --disable-static --with-pic \
           %{?_without_xen} \
           %{?_without_qemu} \
           %{?_without_openvz} \
           %{?_without_lxc} \
           %{?_without_vbox} \
           %{?_without_xenapi} \
           %{?_without_uml} \
           %{?_without_phyp} \
           %{?_without_esx} \
           %{?_without_vmware} \
	   %{?_without_hyperv} \
           %{?_without_libxl} \
           %{?_without_libvirtd} \
           %{?_without_storage_fs} \
           %{?_without_storage_lvm} \
           %{?_without_storage_iscsi} \
           %{?_without_storage_disk} \
           %{?_without_storage_mpath} \
           %{?_without_numactl} \
           %{?_without_selinux} \
           %{?_without_apparmor} \
           %{?_without_capng} \
           %{?_without_netcf} \
           %{?_without_hal} \
           %{?_without_udev} \
           %{?_without_yajl} \
           %{?_without_macvtap} \
           %{?_without_polkit} \
           %{?_without_network} \
           %{?_without_sasl} \
           %{?_without_python} \
           %{?_without_libpcap} \
           --libexecdir=%{_libdir}/%{name} \
           --with-remote-pid-file=%{_localstatedir}/run/libvirtd.pid \
           --with-init-script=redhat \
           ac_cv_path_MODPROBE=/sbin/modprobe \
           ac_cv_path_UDEVADM=/sbin/udevadm \
           ac_cv_path_SHOWMOUNT=/usr/sbin/showmount
make %{?jobs:-j%jobs} DOCS_DIR=%{_docdir}/%{name}-python EXAMPLE_DIR=%{_docdir}/%{name}-python/examples HTML_DIR=%{_docdir}/%{name}

%install
%makeinstall DOCS_DIR=%{_docdir}/%{name}-python EXAMPLE_DIR=%{_docdir}/%{name}-python/examples HTML_DIR=%{_docdir}/%{name}
cp -a AUTHORS ChangeLog COPYING NEWS README TODO $RPM_BUILD_ROOT%{_docdir}/%{name}/
cd docs ; cp -a *.html  $RPM_BUILD_ROOT%{_docdir}/%{name} ; cp -a *.png  $RPM_BUILD_ROOT%{_docdir}/%{name} ; cd ..
# remove currently unsupported locale(s)
rm -rf $RPM_BUILD_ROOT/usr/share/locale/sr@latin
%if 0%{?suse_version} < 1130
rm -rf $RPM_BUILD_ROOT/usr/share/locale/vi_VN
%endif
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/libvirt
rm $RPM_BUILD_ROOT%{_libdir}/*.*a $RPM_BUILD_ROOT%{py_sitedir}/*.*a
%find_lang %{name}
%if %{with_network}
install -d -m 0755 $RPM_BUILD_ROOT%{_localstatedir}/lib/libvirt/dnsmasq/
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%else
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_uml}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.uml
%endif
%if ! %{with_python}
rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}-python
%endif
%if ! %{with_libvirtd}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter
%endif

ln_dupes()
{
    target=""
    fdupes -r "$1" | while read file; do
        if [ -z "$file" ] || [ -z "$target" ]; then
            target="$file"
            continue
        fi
        ln -sf "${target#.}" "$file"
    done
}
(
  cd $RPM_BUILD_ROOT
  ln_dupes .%{_docdir}/%{name}
  ln_dupes ./usr/share/locale
)
# init scripts
mkdir -p $RPM_BUILD_ROOT/etc/init.d
%if %{with_libvirtd}
install %SOURCE1 $RPM_BUILD_ROOT%{_sysconfdir}/init.d/libvirtd
ln -s /etc/init.d/libvirtd $RPM_BUILD_ROOT%{_sbindir}/rclibvirtd
%endif
ln -s /etc/init.d/libvirt-guests $RPM_BUILD_ROOT%{_sbindir}/rclibvirt-guests

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
%if %{with_libvirtd}
%if %{with_network}
# Install the default network if one doesn't exist
if test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml
then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
fi
%endif
%if 0%{?sles_version}
%{fillup_and_insserv -y libvirtd}
%else
%{fillup_only -n libvirtd}
%endif
%endif
%{fillup_only -n libvirt-guests}

%preun
%if %{with_libvirtd}
%stop_on_removal libvirtd
%endif

%postun
/sbin/ldconfig
%if %{with_libvirtd}
%restart_on_update libvirtd
%endif
%insserv_cleanup

%post client -p /sbin/ldconfig

%postun client -p /sbin/ldconfig

%if %{with_libvirtd}

%files
%defattr(-, root, root)
%{_sbindir}/libvirtd
%dir %{_libdir}/%{name}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/
%dir %{_sysconfdir}/sysctl.d
%config %{_sysconfdir}/sysctl.d/libvirtd
%dir %{_libdir}/libvirt/connection-driver
%{_libdir}/libvirt/connection-driver/libvirt_driver_secret.*
%{_libdir}/libvirt/connection-driver/libvirt_driver_nodedev.*
%if %{with_xen}
%{_libdir}/libvirt/connection-driver/libvirt_driver_xen.*
%endif
%if %{with_network}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%{_libdir}/libvirt/connection-driver/libvirt_driver_network.*
%{_libdir}/libvirt/connection-driver/libvirt_driver_nwfilter.*
%endif
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%{_sysconfdir}/libvirt/nwfilter/*.xml
%{_localstatedir}/adm/fillup-templates/sysconfig.libvirtd
%config /etc/init.d/libvirtd
%{_sbindir}/rclibvirtd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_localstatedir}/lib/libvirt/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/
%if %{with_polkit}
%if 0%{?suse_version} > 1110
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%else
%{_datadir}/PolicyKit/policy/org.libvirt.unix.policy
%endif
%endif
%{_datadir}/augeas
%if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%dir %attr(0750, root, root) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, root, root) %{_localstatedir}/cache/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%{_libdir}/libvirt/connection-driver/libvirt_driver_qemu.*
%endif
%if %{with_lxc}
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_lxc
%{_libdir}/libvirt/connection-driver/libvirt_driver_lxc.*
%endif
%if %{with_uml}
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.uml
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/uml/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%endif
%if %{with_libxl}
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%endif
%if %{with_storage_disk}
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_parthelper
%{_libdir}/libvirt/connection-driver/libvirt_driver_storage.*
%endif
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_iohelper
%doc %{_mandir}/man8/libvirtd.8*
%endif

%files client -f %{name}.lang
%defattr(-, root, root)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/[CNRT]*
%doc %{_docdir}/%{name}/AUTHORS
%doc %{_mandir}/man1/virsh.1*
%doc %{_mandir}/man1/virt-xml-validate.1*
%doc %{_mandir}/man1/virt-pki-validate.1*
%doc %{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate
%dir %{_libdir}/%{name}
%{_libdir}/lib*.so.*
%{_localstatedir}/adm/fillup-templates/sysconfig.libvirt-guests
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config /etc/init.d/libvirt-guests
%{_sbindir}/rclibvirt-guests

%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagevol.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storageencryption.rng
%{_datadir}/libvirt/cpu_map.xml
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%if %{with_sasl}
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%endif

%files devel
%defattr(-, root, root)
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvirt.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml

%files doc
%defattr(-, root, root)
%{_datadir}/gtk-doc/html/libvirt
%doc %{_docdir}/%{name}/*.png
%doc %{_docdir}/%{name}/*.html
%doc %{_docdir}/%{name}/*.gif
%doc %{_docdir}/%{name}/*.css
%doc %{_docdir}/%{name}/html

%if %{with_python}

%files python
%defattr(-, root, root)
%doc %{_docdir}/%{name}-python
%{py_sitedir}/libvirt.py*
%{py_sitedir}/libvirtmod*
%{py_sitedir}/libvirt_qemu*
%endif

%changelog
* Sun Aug  5 2012 cs@linux-administrator.com
- Update to libvirt 0.9.13
* Sun Jun 10 2012 cs@linux-administrator.com
- Update to libvirt 0.9.12
  - reworked some patches
* Sat Feb 18 2012 cs@linux-administrator.com
- Update to libvirt 0.9.10
  - reworked some patches
* Wed Sep 28 2011 cs@linux-administrator.com
- Update to libvirt 0.9.6
* Mon Aug  8 2011 cs@linux-administrator.com
- Update to libvirt 0.9.4
  - reworked some patches
* Fri Jul  8 2011 cs@linux-administrator.com
- Update to libvirt 0.9.3
* Mon Jun 27 2011 cs@linux-administrator.com
- enable esx, vmware for SLES build
* Mon Jun  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.2
  - Framework for lock manager plugins
  - API for network config change transactions (netcf required)
  - flags for setting memory parameters
  - virDomainGetState public API
  - qemu: allow blkstat/blkinfo calls during migration
  - Introduce migration v3 API
  - Defining the Screenshot public API
  - public API for NMI injection
- spec file: Adjust some directory attributes to support running
  non-privileged qemu domains
* Sun May 15 2011 jfehlig@suse.de
- Remove vi_VN locale if suse_version < 11.3
* Thu May 12 2011 fcrozat@suse.com
- Enable cap_ng when building lxc support.
* Fri May  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.1
  - support various persistent domain updates
  - improvements on memory APIs
  - Add virDomainEventRebootNew
  - various improvements to libxl drive
  - Spice: support audio, images and stream compression
* Tue Apr 12 2011 jfehlig@suse.de
- Move libvirt-iohelper from client to base package
* Tue Apr 12 2011 coolo@opensuse.org
- fix baselibs.conf not to requires source 32bit
* Mon Apr 11 2011 jfehlig@suse.de
- Install log dir for libxl
  f7e9b448-libxl-build.patch
* Mon Apr  4 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 final
  - Support cpu usage tuning
  - Add public APIs for storage volume upload/download
  - Add public API for setting migration speed on the fly
  - Add libxenlight driver
  - qemu: support migration to fd
  - add virDomain{Get,Set}BlkioParameters
  - introduce a new libvirt API (virDomainSetMemoryFlags)
  - Expose event loop implementation as a public API
  - Dump the debug buffer to libvirtd.log on fatal signal
  - Audit support
  - Numerous enhancements and bug fixes
* Thu Mar 31 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 RC3
* Thu Mar 24 2011 coolo@novell.com
- use %%first_lang before changing symlinks, find_lang removes
  unsupported languages
* Tue Mar 15 2011 jfehlig@novell.com
- VUL-0: libvirt: several API calls do not honour read-only
  connection
  71753cb7-CVE-2011-1146.patch
  bnc#678406
* Mon Mar  7 2011 jfehlig@novell.com
- Add baselibs.conf file to build xxbit packages
  for multilib support
  bnc#676921
* Fri Feb 25 2011 jfehlig@novell.com
- Minor fixes for libvirt-guests
  bnc#653398
* Fri Feb 18 2011 jfehlig@novell.com
- Do not add drive 'boot=on' param when a kernel is specified
  efc2594b-boot-param.patch
* Thu Feb 17 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 final
  - sysinfo: expose new API
  - cgroup blkio weight support
  - smartcard device support
  - qemu: Support per-device boot ordering
* Tue Feb 15 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC3
* Fri Feb 11 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC1
* Mon Jan 31 2011 jfehlig@novell.com
- Remove explicit dependency on libyajl
  libvirt.spec
  bnc#668225
* Fri Jan 21 2011 jfehlig@novell.com
- Retry JSON monitor 'cont' cmd on MigrationExpected error
  4301b95a-json-cont-cmd.patch
* Tue Jan 18 2011 jfehlig@novell.com
- Add support for specifying Hardware Assisted Paging (HAP) in
  libvirt domain XML.
  48a5dccd-hap1.patch
  04197350-hap2.patch
  af521a01-hap3.patch
  79f56c66-hap4.patch
  094c6f4a-hap-fix.patch
  bnc#659665
* Tue Jan 18 2011 jfehlig@novell.com
- Enabled yajl for suse_version >= 1140
* Fri Jan 14 2011 jfehlig@novell.com
- Fix generation of dnsmasq's --dhcp-hostsfile option
  a43c7338-dnsmasq-hostfile-fix.patch
- Disable yajl support as the library does not yet exist in
  SuSE distros.
* Tue Jan 11 2011 jfehlig@novell.com
- Support libvirt-guests on SuSE distros
  use-libvirt-guests-on-suse.patch
  bnc#653398
* Mon Jan  3 2011 jfehlig@novell.com
- Update to libvirt 0.8.7
  - Preliminary support for VirtualBox 4.0
  - IPv6 support
  - Add VMware Workstation and Player driver
  - Add network disk support
* Wed Dec 22 2010 jfehlig@novell.com
- Fix VNC port reservation race in qemu driver
  c58b1056-init-bitmap-size.patch
  bnc#659431
* Fri Dec 10 2010 jfehlig@novell.com
- Do not limit insserv_cleanup to SLES
* Thu Dec  9 2010 jfehlig@novell.com
- disable building openvz driver
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.6
  - new API virDomainIsUpdated
  - Add support for iSCSI target auto-discovery
  - QED: Basic support for QED images
  - Introduce a virDomainOpenConsole API
  - Support for SPICE graphics
  - Add a sysinfo and SMBIOS support
  - Implement virsh qemu-monitor-command
- Enabled yajl, macvtap, and virtualport for suse_version >= 1140
* Mon Nov  1 2010 jfehlig@novell.com
- Fix build when using "policy kit 0"
  polkit0.patch
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.5
  - Enable JSON and netdev features in QEMU > 0.13
  - framework for auditing integration
  - framework for DTrace/SystemTap integration
  - Setting the number of vcpu at boot
  - Enable support for nested SVM
  - Virtio plan9fs filesystem QEMU
  - Memory parameter controls
  - portability to OS-X
  - lot of bug fixes and other improvements
* Wed Oct 13 2010 jfehlig@novell.com
- cannot restart dead libvirtd without manually removing pidfile
  modified libvirtd.init
  bnc#645755
* Mon Oct 11 2010 cristian.rodriguez@opensuse.org
- Fix package dependencies so can be installed without
  pulling excess of optional components
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Support dropping capabilities with cap-ng library in
  openSUSE >= 11.3
* Tue Sep 28 2010 jfehlig@novell.com
- Fix build when virtualport support is available but macvtap is
  disabled.
  vport-configure.patch
* Thu Sep 23 2010 jfehlig@novell.com
- Fix CDROM media change for Xen PV domains
  modified xen-pv-cdrom.patch
  bnc#636231
* Fri Sep 10 2010 jfehlig@novell.com
- Update to libvirt 0.8.4
  - various improvements to UML driver
  - documentation improvements
  - lot of bug fixes and other improvements
  - enable ESX driver for openSUSE
* Sat Aug  7 2010 jfehlig@novell.com
- Update to libvirt 0.8.3
  - Support vSphere 4.1
  - Qemu arbitrary monitor commands
  - Qemu Monitor API entry point
  - lots of improvements and bug fixes
* Fri Jul  9 2010 jfehlig@novell.com
- VUL-0: multiple issues in libvirt
  CVE-2010-223x-000[1-0].patch, CVE-2010-223x-0010.patch,
  CVE-2010-2242-nat.patch
  bnc#618155
* Fri Jun 25 2010 jfehlig@novell.com
- Use netcat-openbsd, which contains a proper 'nc' program
  supporting the '-U' option.  Drop socat.patch.
  bnc#611023
* Mon Jun 21 2010 jfehlig@novell.com
- Re-enable numa support now that bnc#598488 is resolved.
* Fri Jun  4 2010 jfehlig@novell.com
- Allocate buffer to hold xend content
  bnc#609738
  xend-buff-size.patch
- Add upstream fixes to bitmap code that was introduced to fix
  bnc#594024
  bitmap-alloc.patch
  bitmap-fixes.patch
* Tue Jun  1 2010 jfehlig@novell.com
- Fix race in VNC port reservation with qemu/KVM domains
  bnc#594024
  vnc-race-{1,2,3}.patch
* Wed May 12 2010 jfehlig@novell.com
- Don't package directories/files under /var/run
- Add upstream commit 34a7f3f6 to fix unintentional breakage of
  RPC protocol.
- Disable numa support in openSUSE11.3/Factory pending resolution
  of bnc#598488
* Fri Apr 30 2010 jfehlig@novell.com
- Update to libvirt 0.8.1
  - Add virDomainGetBlockInfo API to query disk sizing
  - Start dnsmasq from libvirtd with --dhcp-hostsfile option
  - lots of improvements and bug fixes
* Tue Apr 13 2010 jfehlig@novell.com
- Update to libvirt 0.8.0
  - Snapshot API framework
  - Add managed save API entry points
  - Timer subselection for domain clock
  - Add hook utilities
  - Network filtering API
  - Introduce a new virDomainUpdateDeviceFlags public API
  - Introduce a new public API for domain events
  - Public virDomainMigrateSetMaxDowntime API
  - Add public API for volume wiping
  - xenapi: Initial commit of the new driver
  - lots of improvements and bug fixes
* Fri Mar 26 2010 jfehlig@novell.com
- Fix 'virsh dominfo' crash when no security driver is configured
  fix-no-secdriver.patch
* Mon Mar 22 2010 jfehlig@novell.com
- Updated to version 0.7.7
  - Introduce public API for domain async job handling
  - macvtap support
  - Add QEMU support for virtio channel
  - Add persistence of PCI addresses to QEMU
  - Functions for computing baseline CPU from a set of host CPUs
  - Public API for virDomain{Attach,Detach}DeviceFlags
  - lots of improvements and bug fixes
* Tue Mar  9 2010 jfehlig@novell.com
- Ensure yast-created bridges are not manipulated by libvirt
  bnc#584757
  Modified suse-network.patch
* Thu Mar  4 2010 jfehlig@novell.com
- Fix ordering of xen disks to preserve 'bootable' flag
  bnc#474738
  xend-disk-order.patch
- Add support for blktap2 disks
  xen-tap2-support.patch
* Mon Mar  1 2010 jfehlig@novell.com
- Fix listing of yast-created bridges
  bnc#583754
  Modified suse-network.patch
* Mon Feb 22 2010 jfehlig@novell.com
- Add support for new XEN_DOMCTL_INTERFACE_VERSION version 7.
  xen-domctl-ver7.patch
* Mon Feb 15 2010 jfehlig@novell.com
- Unconditionally add /var/log/libvirt/{qemu,lxc,uml} directories.
  bnc#579522
* Thu Feb  4 2010 jfehlig@novell.com
- Updated to version 0.7.6
  - Implement support for multi IQN
  - Implement CPU topology support for QEMU driver
  - Use QEmu new device adressing when possible
  - Implement SCSI controller hotplug/unplug for QEMU
  - lots of improvements and bug fixes
* Thu Jan 28 2010 jfehlig@novell.com
- Support new XEN_SYSCTL_INTERFACE_VERSION 7 in libvirt
  bnc#574124
  xen-sysctl-v7.patch
- Add upstream patches as prelude to fixing various device
  attach/detach issues
  devflag-0[1-9].patch
- Fix attaching/detaching disk device from inactive Xen guest
  bnc#500586 and bnc#573748
* Tue Jan 12 2010 jfehlig@novell.com
- Fix migration with Xen4.0
  bnc#569598
  Add xen-migration-params.patch
  Remove migrate-params.patch
* Thu Jan  7 2010 jfehlig@novell.com
- Fix freeing of uninitialized pointer when using HAL in
  node device driver
  node-dev-free.patch
* Mon Jan  4 2010 jfehlig@novell.com
- Require virt-utils package for common tools such as qemu-img
* Tue Dec 29 2009 jfehlig@novell.com
- Updated to version 0.7.5
  - Add new API virDomainMemoryStats to header and drivers
  - Public API and domain extension for CPU flags
  - expose SR IOV physical/virtual function relationships
  - Support for JSON mode monitor [deactivated]
  - Support for interface model='netfront'
  - vbox: Add support for version 3.1
  - Support QEMU's virtual FAT block device driver
  - lots of improvements and bug fixes
- Fix libvirt xen hypervisor driver to work with domctl interface
  version 6
  xen-shr-pages.patch
* Mon Dec  7 2009 jfehlig@novell.com
- Plumb domain description in xend backend
  xend-description-tag.patch
* Wed Nov 25 2009 jfehlig@novell.com
- Fix listing of defined but inactive Xen domains
  xen-list-defined.patch
* Tue Nov 24 2009 jfehlig@novell.com
- Updated to version 0.7.4
  - Implement a node device backend using libudev
  - New APIs for checking some object properties
  - Fully asynchronous monitor I/O processing
  - add MAC address based port filtering to qemu
  - support for IPv6 / multiple addresses per interfaces
  - lots of improvements and bug fixes
* Thu Nov 19 2009 jfehlig@novell.com
- Fix compilation against xen-unstable
  xen-max-vcpus.patch
- Modify detach-disk.patch as per upstream suggestions
* Thu Nov  5 2009 jfehlig@novell.com
- spec file: Fix polkit vs PolicyKit Requires
* Mon Oct 19 2009 jfehlig@novell.com
- Fix compilation when selinux is enabled
  selinux-ldflags.patch
- Fix compilation warnings
  updated snapshots.patch
  virsh-warning.patch
* Fri Oct 16 2009 jfehlig@novell.com
- Updated to version 0.7.2
  - sVirt AppArmor security driver
  - Add public API definition for data stream handling
  - ESX add esxDomainDefineXML()
  - LXC: suspend/resume support
  - Big code tree cleanup
  - Lots of bug fixes and improvements
* Tue Oct 13 2009 jfehlig@novell.com
- Add ocfs2 to list of supported fs pool types
  fate#307387
* Tue Oct 13 2009 jfehlig@novell.com
- Build phyp driver ifarch ppc64
  fate#307096
- Fix memory leaks in libvirtd's message processing
  msg-proc-memleak.patch
* Tue Sep 29 2009 jfehlig@novell.com
- Fix connection ref counting in xen drivers
  xen-refcnt.patch
* Fri Sep 25 2009 jfehlig@novell.com
- Fix abort in virsh when specifying a connection URI
  vshdeinit-recurse.patch
* Wed Sep 23 2009 jfehlig@novell.com
- Workaround for missing pkgconfig file in device-mapper-devel
  devmap-no-pkgconfig.patch
  bnc#540942
* Mon Sep 21 2009 jfehlig@novell.com
- Updated to version 0.7.1
  - Add support for encrypted (qcow) volume creation
  - Secret manipulation public API
  - Multipath storage support module
  - VBox add Storage Volume support
  - Support configuration of huge pages in guests
  - Support new PolicyKit 1.0 API
  - Compressed save image format for Qemu
  - Qemu add host PCI device hotplug support
* Wed Aug 26 2009 jfehlig@novell.com
- Updated to version 0.7.0
  - Interface implementation based on netcf (disabled on SuSE)
  - Add new net filesystem glusterfs
  - Initial VMWare ESX driver
  - Add support for VBox 3 and event callbacks on vbox
  - First version of the Power Hypervisor driver
  - Run QEMU guests as an unprivileged user (still root on SuSE)
  - Support cgroups in QEMU driver
  - QEmu hotplug NIC support
  - Storage cloning for LVM and Disk backends
* Tue Jul  7 2009 jfehlig@novell.com
- Updated to version 0.6.5
  - create storage volumes on disk backend
  - drop of capabilities based on libcap-ng when possible
  - forbid autostart on transcient networks
  - re-detection of transient VMs after libvirtd restart
  - create and destroy NPIV support
  - other bug fixes and cleanups
* Fri Apr 24 2009 jfehlig@novell.com
- Removed unnecessary call to fillup_and_insserv macro in
  %%post scriptlet
* Wed Apr 22 2009 jfehlig@novell.com
- Updated to version 0.6.2
  - support SASL auth for VNC server
  - memory ballooning in QEMU
  - SCSI HBA storage pool support
  - PCI passthrough in Xen driver
  - new APIs for Node device detach reattach and reset
  - sVirt mandatory access control support
  - thread safety of the API and event handling
  - allow QEmu domains to survive daemon restart
  - extended logging capabilities
  - support copy-on-write storage volumes
  - support of storage cache control options for QEMU/KVM
- Improvements from lnussel@suse.de
  - add %%jobs macro again
  - package default qemu network and augeas config files again
  - don't start libvirtd by default (bnc#496838)
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of just removing static libraries
* Fri Jan 30 2009 jfehlig@novell.com
- Fix build for architectures not supporting numa
- Forward port suse-network.patch and snapshots.patch
* Wed Jan 28 2009 jfehlig@novell.com
- Updated to version 0.5.1
  - CPU and scheduler support for LXC
  - SDL display configuration
  - domain lifecycle event support for QEmu and Xen with python
    bindings
  - KVM/QEmu migration support
  - User Mode Linux driver
  - API for node device enumeration using HAL and DeviceKit with
    python bindings
  - Many bug fixes and improvements
* Fri Jan  9 2009 jfehlig@novell.com
- Added missing html and png files to libvirt-doc package
  devhelp.patch
  bnc#463810
* Mon Dec 15 2008 jfehlig@novell.com
- Patch for CVE-2008-5086
  bnc#459009
* Fri Dec  5 2008 jfehlig@novell.com
- Fix migration of Xen domains
  bnc#456946
* Tue Dec  2 2008 jfehlig@novell.com
- Refresh xen-maxmem.patch to match upstream
  bnc#431766
* Tue Nov 25 2008 jfehlig@novell.com
- Add network to Required-Start in libvirtd init script
  bnc#448756
* Mon Nov 24 2008 jfehlig@novell.com
- Fix connecting/disconnecting ISO via virt-manager
  bnc#446773
* Fri Nov 21 2008 jfehlig@novell.com
- Fix detach of Xen tap devices
  bnc#410644 and bnc#411633
* Fri Nov  7 2008 jfehlig@novell.com
- Fix handling of iso/cdrom for xen pv domains.
  bnc#437388
* Wed Nov  5 2008 jfehlig@novell.com
- Expose networks managed outside of libvirt as read-only.
  bnc#441633
* Wed Nov  5 2008 jfehlig@novell.com
- Fix vnc port assignement in domain XML
  bnc#441625
* Thu Oct 23 2008 jfehlig@novell.com
- Add upstream patches to fix ordering problem with setting up
  cgroup containment on LXC domains.
  bnc#437816
* Mon Oct 20 2008 jfehlig@novell.com
- Remove IA64 from list of architectures supporting Xen.
* Fri Oct 10 2008 jfehlig@novell.com
- Added upstream patches providing additional LXC support
  bnc#433881
* Mon Oct  6 2008 jfehlig@novell.com
- Use xend vs hypercall interface to change max mem setting
  bnc#431766
* Wed Oct  1 2008 jfehlig@novell.com
- Enabled libvirtd listen mode in libvirtd init script.
* Wed Oct  1 2008 jfehlig@novell.com
- Updated to version 0.4.6
  - avoid a segfault if missing qemu emulator
  - reading vncdisplay from xend domain
  - segfault in OpenVZ
  - fix parsing of pool without a source
- Fixed bug in network interface parsing
  - vif-parsing.patch submitted upstream
* Tue Sep 16 2008 jfehlig@novell.com
- open-iscsi package required for iscsi storage backend
* Mon Sep 15 2008 jfehlig@novell.com
- Updated to version 0.4.5
  - NETNS support for Linux containers
  - unified XML domain and network parsing for all drivers
  - OpenVZ features improvements
  - OpenVZ and Linux containers support now default
  - USB device passthrough for QEmu/KVM
  - storage pool source discovery
  - other bug fixes and improvements
* Thu Sep  4 2008 kwolf@suse.de
- Added Python bindings for the snapshot functions
* Wed Sep  3 2008 kwolf@suse.de
- Implemented listing of snapshots for Xen and in virsh
* Tue Sep  2 2008 kwolf@suse.de
- Added snapshot support. Implemented snapshot_create/apply/delete
  for Xen.
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in nfs storage pool creation/deletion
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in LVM storage pool creation.
  logical-storage-driver.patch submitted upstream
* Wed Aug 27 2008 jfehlig@novell.com
- Changed mDNS advertisement of libvirtd service to disabled by
  default.  Enable in libvirtd.conf.
- Disable libvirtd from listening on TLS socket by default.  User
  must enable after setting up CA and issuing certificates.
* Mon Aug 25 2008 jfehlig@novell.com
- Enabled iscsi storage driver support
- Enabled ssh transport using socat.  SuSE's version of netcat
  does not support connecting to UDS.
- Fixed spec file breakage due to SELinux enablement
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Tue Aug 12 2008 jfehlig@novell.com
- Cleanup of libvirtd init script
- Removed dnsmasq from BuildRequires
* Sat Aug  9 2008 jfehlig@novell.com
- Adjustments to spec file
  + Added /var/lib/libvirt directory
  + Enabled LXC support if suse_version > 1100, fate #304001
  + Cleaned up some rpmlint warnings
* Sun Jul  6 2008 jfehlig@novell.com
- Updated to libvirt 0.4.4
  + Bug fixes: QEmu network serialization, internal memory allocation
    fixes, virsh large file config problem, xen list APIs when max is
    zero, string escape problems in the xm driver
  + Improvements: add autogen to tarballs, improve iSCSI support
  + Cleanups: const-ness fixed, string helpers for enumeations
- spec file adjustments
  + Remove ExclusiveArch
  + Common spec file for all products
  + Support for building/running without Xen
* Fri May  9 2008 jfehlig@novell.com
- Adjust libvirtd PolicyKit configuration file to match standard
  suse procedures.  bnc#388769
* Mon May  5 2008 jfehlig@novell.com
- Fix path to iptables.  bnc#386280
* Thu Apr 24 2008 jfehlig@novell.com
- Fix Xen 3.2 hypercalls.  bnc#378798
* Thu Apr 10 2008 jfehlig@novell.com
- Fix NULL pointer dereference in auth callback.  bnc#373180,
  bnc#354995
* Wed Jan  9 2008 jfehlig@novell.com
- Remove Requires of nc package.  netcat is the equivalent but it
  does not support unix domain sockets so no need to require it
  either.
* Tue Jan  8 2008 coolo@suse.de
- do not require a non existant package, but change it to a recommend
  to digestmd5
* Fri Jan  4 2008 jfehlig@novell.com
- Updated to libvirt-0.4.0
  - SASL based authentication for libvirt remote support
  - PolicyKit authentication
  - Documentation: example files for QEMU and libvirtd configuations,
    authentication documentation updates
  - Bug fixes, improvements and code cleanup
* Tue Oct  9 2007 jfehlig@novell.com
- Updated to libvirt 0.3.3
  - Avahi mDNS daemon export
  - NUMA support
  - Bug fixes
- Cleanup rpmlint warnings
* Mon Oct  8 2007 jfehlig@novell.com
- Removed 'jobs' option from make invocation in spec file.  Appears
  to be a subtle dependency issue in one of the makefiles which is
  causing problems with generation of python bindings when jobs > 1.
  Bug #329032.
* Mon Aug 20 2007 jfehlig@novell.com
- Added init script for libvirtd.  libvirtd is needed to support
  management of qemu/kvm guests.  Some Xen networking is handled
  through libvirt as well - bug #298021.
* Mon Jul 23 2007 jfehlig@novell.com
- Update to libvirt-0.3.0
  - Secure Remote support
  - Documentation: remote support, description of the URI connection
    strings, update of virsh man page, matrix of libvirt API/hypervisor
    support with version informations
  - Bug fixes: examples Makefile.am generation, SetMem fix, URI
    handling and ordering of drivers, fix virsh help without hypervisor,
    id marshalling fix, fix virConnectGetMaxVcpus on remote, avoid
    a realloc leak, scheduler parameters handling for Xen, various
    early remote bug fixes, remove virsh leaks of domains references,
    configCache refill bug, fix XML serialization bugs
  - Improvements: QEmu switch to XDR-based protocol, device attach/detach
    commands OCaml bindings, new entry points virDomainGetConnect and
    virNetworkGetConnect useful for bindings, reunitifaction of remote
    and qemu daemon under a single libvirtd with a config file
  - Cleanups: parsing of connection URIs, messages from virsh,
    Coverage files, Solaris fixes, avoid [r]index calls, release
    information in Xen backend, virsh cpupin command cleanups,
    xen:/// suppport as standard Xen URI, improve driver
    selection/decline mechanism, error reporting on XML dump,
    Remove unused virDomainKernel structure, daemon event loop event
    handling, various unifications cleanup in the daemon merging,
    internal file and timer monitoring API, remove libsysfs dependancy,
    call brctl program directly, virBuffer functions cleanups,
    make init script LSB compliant, error handling on lookup functions,
    remove internal virGetDomainByID, revamp of xen subdrivers interfaces
  - Localization updates
* Tue Jun 12 2007 ccoffing@novell.com
- Update to libvirt-0.2.3.
- Fix duplicate files found by rpmlint.
* Wed May 23 2007 ccoffing@novell.com
- Fix rpmlint errors.
* Fri Apr 27 2007 ccoffing@novell.com
- Update to libvirt-0.2.2.
* Wed Mar  7 2007 sbrabec@suse.cz
- Created -doc subpackage (#248813).
- Do not remove valid locales.
- Fixed docdir destination.
- Build with CFLAGS.
- Spec file cleanup.
* Tue Feb 20 2007 jfehlig@novell.com
- Removed usr/lib/libvirt_proxy setuid binary from package.  Fixes
  bug #246610.
* Sat Feb 17 2007 jfehlig@novell.com
- Updated to latest release.  Many of the issues seen in virt-manager
  have been caused by bugs / missing functionality in libvirt.  This
  upate provides a better basis for virt-manager.
* Thu Jan 11 2007 jfehlig@novell.com
- Updated to latest release, version 0.1.10.  Submitting to SLES10 SP1
  to provide base functionality for FATE feature 301181.
  - more localizations
  - bug fixes:
  - VCPU info breakages on xen 3.0.3
  - xenDaemonListDomains buffer overflow (Daniel Berrange)
  - reference count bug when creating Xen domains (Daniel Berrange)
  - improvements:
  - support graphic framebuffer for Xen paravirt (Daniel Berrange)
  - VNC listen IP range support (Daniel Berrange)
  - support for default Xen config files and inactive domains of 3.0.4 (Daniel Berrange)
* Fri Dec  8 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.9.
  - python bindings: release interpeter lock when calling C (Daniel Berrange)
  - don't raise HTTP error when looking informations for a domain
  - some refactoring to use the driver for all entry points
  - better error reporting (Daniel Berrange)
  - fix OS reporting when running as non-root
  - provide XML parsing errors
  - extension of the test framework (Daniel Berrange)
  - fix the reconnect regression test
  - python bindings: Domain instances now link to the Connect to avoid garbage collection and disconnect
  - separate the notion of maximum memory and current use at the XML level
  - Fix a memory leak (Daniel Berrange)
  - add support for shareable drives
  - add support for non-bridge style networking configs for guests(Daniel Berrange)
  - python bindings: fix unsigned long marshalling (Daniel Berrange)
  - new config APIs virConfNew() and virConfSetValue() to build configs from scratch
  - hot plug device support based on Michel Ponceau patch
  - added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)
  - special device model for HVM guests (Daniel Berrange)
  - add API to dump core of domains (but requires a patched xend)
  - pygrub bootloader informations take over <os> informations
  - updated the localization strings
* Fri Oct 20 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.8.
  - Bug for system with page size != 4k
  - vcpu number initialization (Philippe Berthault)
  - don't label crashed domains as shut off (Peter Vetere)
  - fix virsh man page (Noriko Mizumoto)
  - blktapdd support for alternate drivers like blktap (Daniel Berrange)
  - memory leak fixes (xend interface and XML parsing) (Daniel Berrange)
  - compile fix
  - mlock/munlock size fixes (Daniel Berrange)
  - improve error reporting
- Updated to latest release, version 0.1.7.
  - fix a memory bug on getting vcpu informations from xend (Daniel Berrange)
  - fix another problem in the hypercalls change in Xen changeset
    86d26e6ec89b when getting domain informations (Daniel Berrange)
* Tue Sep 26 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.6.  This release includes
  fix in hypercall driver so local patch has been removed.
* Wed Sep 13 2006 jfehlig@novell.com
- Fixed bug in hypercall driver introduced in version 0.1.5.
  Patch sumbmitted upstream and included locally until next release.
* Mon Sep 11 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.5
  - Support for new hypercalls change in Xen changeset 86d26e6ec89b
  - bug fixes: virParseUUID() was wrong, netwoking for paravirt guestsi
    (Daniel Berrange), virsh on non-existent domains (Daniel Berrange),
    string cast bug when handling error in python (Pete Vetere), HTTP
    500 xend error code handling (Pete Vetere and Daniel Berrange)
  - improvements: test suite for SEXPR <-> XML format conversions (Daniel
    Berrange), virsh output regression suite (Daniel Berrange), new environ
    variable VIRSH_DEFAULT_CONNECT_URI for the default URI when connecting
    (Daniel Berrange), graphical console support for paravirt guests
    (Jeremy Katz), parsing of simple Xen config files (with Daniel Berrange),
    early work on defined (not running) domains (Daniel Berrange),
    virsh output improvement (Daniel Berrange
* Mon Aug 28 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.4
  - bug fixes: spec file fix (Mark McLoughlin), error report problem (with
    Hugh Brock), long integer in Python bindings (with Daniel Berrange), XML
    generation bug for CDRom (Daniel Berrange), bug whem using number() XPath
    function (Mark McLoughlin), fix python detection code, remove duplicate
    initialization errors (Daniel Berrange)
  - improvements: UUID in XML description (Peter Vetere), proxy code
    cleanup, virtual CPU and affinity support + virsh support (Michel
    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
    for console in XML (Daniel Berrange), added XML dump to driver and proxy
    support (Daniel Berrange), extention of boot options with support for
    floppy and cdrom (Daniel Berrange), features block in XML to report/ask
    PAE, ACPI, APIC for HVM domains (Daniel Berrange), fail saide-effect
    operations when using read-only connection, large improvements to test
    driver (Daniel Berrange)
  - documentation: spelling (Daniel Berrange), test driver examples.
* Wed Aug 16 2006 jfehlig@novell.com
- Added ExclusiveArch tag so as to only build on x86 and x86_64
* Mon Jul 31 2006 jfehlig@novell.com
- initial submission of libvirt package, version 0.1.3
